# Everyware Starter Package
 
__Development requirements__
* [Docker environment](https://docs.docker.com/docker-for-mac/install/) - Will include nginx, MySQL, Redis and support for PHP 7.2
* [composer](#markdown-header-composer) - Dependency management for PHP
* [npm and Node.js](https://docs.npmjs.com/downloading-and-installing-node-js-and-npm) - Dependency management for Javascript

## Getting started

Regular Wordpress installation depends on Everyware and EveryBoard plugins.

To create the dev environment you should follow the steps and install the required software.
When all required software is installed it is time to setup your environment.

By running following command lets you install all necessary packages you need through `composer`, `npm` and will also download and prepare WordPress. 

```bash
# Kick start the project and install packages and download WordPress
$ ./bin/init.sh
```

After that you will use **[Makefile](#markdown-header-makefile)** to start your project.

```bash
$ make start
```

### Setting up .env-variables
When you have called the command `./bin/init.sh` you will get a `.env` file in the root-folder.
From this file you can set up every thing for your application.

### When "up and running"
Before we begin we have to check a few things.
Make a host redirect for your dev-domains in the system host-file.

```bash
127.0.0.1 everywarestarterkit.local
127.0.0.1 site.everywarestarterkit.local
```

> Mac: /etc/hosts  

Now go to the url of your local installation of wordpress(the url set up from docker) and log in to [wp-admin](everywarestarterkit.local/wp-admin):
1. From `My Sites->Network Admin->themes`: make sure the themes are network enabled.
2. Now make sure the __sites__ have the requiring plugins and theme.

### Everyware Structure theme
In the `wp-content/themes` directory you will now have access to a basic structure theme with the necessary files required to build
a WordPress theme for Everyware.  

_All done!_

## Documentation

### Makefile
We have a *Makefile* that can be used to handle docker commands.
You can find the list och available commands in the file which is located in project-root 

Example of commands:
```bash
$ make start                        # Starts all Docker containers for project
$ make stop                         # Stops all Docker containers for project
$ make pull                         # Download latest version of Docker containers

$ make luarocks                     # You only have to this once on first start

$ make composer                     # Run composer through container

$ make redis-flush                  # Flush redis
```

### Bin scripts
We have some nice to have script as bin scripts which helps you with stuff in day to day work 
```bash
$ ./bin/init.sh                     # Kick start the project and install all you need
$ ./bin/update.sh                   # Shorthand to update composer, npm and such. Maybe after git pull?

$ ./bin/wordpress-update-salt.sh    # Updates WordPress salt
```

### Must use plugin
Everyware Starter Package have one must have plugin which is mandatory and will always be activated.    
It's located under `www/wp-content/mu-plugin/`.

### [Composer](https://getcomposer.org/)
The project php is handled by `composer`. You can find the configuration in `composer.json`.
Here you will find dependencies, code standard, namespaces etc.

Instructions on how to install composer can be found [here](https://getcomposer.org/doc/00-intro.md#installation-linux-unix-osx).  

When you have composer installed globally, run the following command from the `project-root`:

```bash
$ composer install
or 
$ make composer install
```

If you add dependencies i composer or if you want to update current dependencies use:

```bash
$ composer update
or 
$ make composer update
```

### Log files
Log files are automatically created in the project folder in the subfolder "log".

```bash
access.log              # (nginx access log)

error.log               # (nginx error log)

php-fpm-error.log       # (php-fpm error log)
```

Follow logs with

```bash
$ tail -f log/error.log
```
## In Production
### Release
We have created a command that helps you to

* Bump version
* Commit and tag
  
```bash
$ ./bin/create-release.sh
```

Then you get option of what type of version you want to release: `Major`, `Minor` & `Patch`. And this script will helps you to update and create 
tags with **semantic versioning**

### CHANGELOG
Don't forget to update CHANGELOG.md with the changes made so it's easy for other developer 
to see what have happened.
