#!/usr/bin/env bash

source $(dirname "$0")/utilis/colors.sh

version=${version:-4.9.4}
languages=("US" "SE" "DK")

function SetDownloadUrl () {
    local language=${1}
    case ${language} in
        "US" )
        url="https://wordpress.org/wordpress-${version}.tar.gz"
        ;;
        "SE" )
        url="https://sv.wordpress.org/wordpress-${version}-sv_SE.tar.gz"
        ;;
        "DK" )
        url="http://da.wordpress.org/wordpress-${version}-da_DK.tar.gz"
        ;;
    esac
    echo $url
}

# Read script arguments for language
while [[ "$1" != "" ]]; do
    case $1 in
        -l | --language )
            shift
            if [[ ! ${1} == "" ]]; then
                language=$(echo $1 | awk '{print toupper($0)}')
                for lan in "${languages[@]}"; do
                    [[ ${language} == ${lan} ]] && wordpressUrl=$(SetDownloadUrl "${language}")
                done
            fi
            ;;
    esac
    shift
done

# Prompt for language when not provided
if [[ ${wordpressUrl} == "" ]]; then
    echo "${GREEN}${BOLD}> Language of WordPress installation?${RESET}"
    PS3="Option?"
    select language in ${languages[@]}; do
        wordpressUrl=$(SetDownloadUrl "${language}")
        break
    done
fi

echo "${GREEN}${BOLD}> Downloading WordPress from ${wordpressUrl}${RESET}"
curl -L -o ./tmp/wordpress.tar.gz --create-dirs ${wordpressUrl}

echo "${GREEN}${BOLD}> Unpacking${RESET}"
tar -zxf ./tmp/wordpress.tar.gz -C ./tmp/
rsync -a ./tmp/wordpress/ ./www/

sh ./bin/wordpress-update-salt.sh

echo "${GREEN}${BOLD}> Cleaning up${RESET}"
rm -rf ./tmp*
rm -rf ./www/wp-content/themes/twenty*
rm -rf ./www/wp-content/languages/themes/twenty*
rm -rf ./www/wp-content/plugins/hello.php
rm -rf ./www/wp-content/plugins/akismet
rm -rf ./www/wp-content/languages/plugins/akismet*
rm -rf ./www/wp-config-sample.php

echo "${GREEN}${BOLD}> DONE!${RESET}"
